==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Armazenamento indisposinvel",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro Desconhecido",
    "Could not move %s - File with this name already exists" : "Não foi possível mover %s - Já existe um ficheiro com este nome",
    "Could not move %s" : "Não foi possível mover %s",
    "Permission denied" : "Permissão negada",
    "The target folder has been moved or deleted." : "A pasta de destino foi movida ou eliminada.",
    "The name %s is already used in the folder %s. Please choose a different name." : "O nome %s já está em uso na pasta %s. Por favor escolha um nome diferente.",
    "Error when creating the file" : "Erro ao criar o ficheiro",
    "Error when creating the folder" : "Erro ao criar a pasta",
    "Unable to set upload directory." : "Não foi possível criar o diretório de upload",
    "Invalid Token" : "Token inválido",
    "No file was uploaded. Unknown error" : "Não foi enviado nenhum ficheiro. Erro desconhecido",
    "There is no error, the file uploaded with success" : "Não ocorreram erros, o ficheiro foi enviado com sucesso",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "O ficheiro enviado excede a diretiva php.ini upload_max_filesize no php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva MAX_FILE_SIZE definida  no formulário HTML",
    "The uploaded file was only partially uploaded" : "O ficheiro submetido só foi parcialmente enviado",
    "No file was uploaded" : "Não foi enviado nenhum ficheiro",
    "Missing a temporary folder" : "A pasta temporária está em falta",
    "Failed to write to disk" : "Não foi possível gravar no disco",
    "Not enough storage available" : "Não há espaço suficiente em disco",
    "Upload failed. Could not find uploaded file" : "Falhou o envio. Não conseguiu encontrar o ficheiro enviado",
    "Upload failed. Could not get file info." : "O carregamento falhou. Não foi possível obter a informação do ficheiro.",
    "Invalid directory." : "Diretoria inválida.",
    "Files" : "Ficheiros",
    "All files" : "Todos os ficheiros",
    "Favorites" : "Favoritos",
    "Home" : "Casa",
    "Close" : "Fechar",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Incapaz de enviar {filename}, dado que é uma pasta, ou tem 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "O tamanho total do ficheiro {size1} excede o limite de carregamento {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente. Está a enviar {size1} mas apenas existe {size2} disponível",
    "Upload cancelled." : "Envio cancelado.",
    "Could not get result from server." : "Não foi possível obter o resultado do servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de ficheiro em progresso. Se deixar a página agora, irá cancelar o envio.",
    "Actions" : "Ações",
    "Download" : "Descarregar",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Error moving file." : "Erro a mover o ficheiro.",
    "Error moving file" : "Erro ao mover o ficheiro",
    "Error" : "Erro",
    "{new_name} already exists" : "O nome {new_name} já existe",
    "Could not rename file" : "Não pôde renomear o ficheiro",
    "Could not create file" : "Não pôde criar ficheiro",
    "Could not create folder" : "Não pôde criar pasta",
    "Error deleting file." : "Erro ao apagar o ficheiro.",
    "No entries in this folder match '{filter}'" : "Nenhumas entradas nesta pasta correspondem a '{filter}'",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A carregar %n ficheiro","A carregar %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheiro. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheiro ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Assinalado como Favorito",
    "Favorite" : "Favorito",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt",
    "Folder" : "Pasta",
    "New folder" : "Nova Pasta",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as tags",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite notificações sobre a criação e modificações nos seus <strong>ficheiros favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Foi <strong>apagado</strong> um ficheiro ou pasta",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado(a)</strong> um ficheiro ou pasta",
    "You created %1$s" : "Criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado numa pasta pública",
    "You changed %1$s" : "Alterou %1$s",
    "%2$s changed %1$s" : "%2$s alterou %1$s",
    "You deleted %1$s" : "Apagou %1$s",
    "%2$s deleted %1$s" : "%2$s apagou %1$s",
    "You restored %1$s" : "Restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "%s could not be renamed as it has been deleted" : "Não foi possível renomear %s devido a ter sido eliminado",
    "%s could not be renamed" : "%s não pode ser renomeada",
    "Upload (max. %s)" : "Enviar (max. %s)",
    "File handling" : "Manuseamento do ficheiro",
    "Maximum upload size" : "Tamanho máximo de envio",
    "max. possible: " : "Máx. possível: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Com PHP-FPM este valor poderá demorar até 5 minutos para ser aplicado depois de guardar.",
    "Save" : "Guardar",
    "Can not be edited from here due to insufficient permissions." : "Não pode ser editado a partir daqui devido a permissões insuficientes.",
    "Settings" : "Definições",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilize esta ligação para <a href=\"%s\" target=\"_blank\">aceder aos seus ficheiros via WebDAV</a>",
    "Cancel upload" : "Cancelar o envio",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Carregue algum conteúdo ou sincronize com os seus aparelhos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Seleccionar todos",
    "Upload too large" : "Upload muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiro que está a tentar enviar excedem o tamanho máximo de envio neste servidor.",
    "Files are being scanned, please wait." : "Os ficheiros estão a ser analisados, por favor aguarde.",
    "Currently scanning" : "A analisar",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/pt_PT.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Armazenamento indisposinvel",
    "Storage invalid" : "Armazenamento inválido",
    "Unknown error" : "Erro Desconhecido",
    "Unable to set upload directory." : "Não foi possível criar o diretório de upload",
    "Invalid Token" : "Token inválido",
    "No file was uploaded. Unknown error" : "Não foi enviado nenhum ficheiro. Erro desconhecido",
    "There is no error, the file uploaded with success" : "Não ocorreram erros, o ficheiro foi enviado com sucesso",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "O ficheiro enviado excede a diretiva php.ini upload_max_filesize no php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva MAX_FILE_SIZE definida  no formulário HTML",
    "The uploaded file was only partially uploaded" : "O ficheiro submetido só foi parcialmente enviado",
    "No file was uploaded" : "Não foi enviado nenhum ficheiro",
    "Missing a temporary folder" : "A pasta temporária está em falta",
    "Failed to write to disk" : "Não foi possível gravar no disco",
    "Not enough storage available" : "Não há espaço suficiente em disco",
    "The target folder has been moved or deleted." : "A pasta de destino foi movida ou eliminada.",
    "Upload failed. Could not find uploaded file" : "Falhou o envio. Não conseguiu encontrar o ficheiro enviado",
    "Upload failed. Could not get file info." : "O carregamento falhou. Não foi possível obter a informação do ficheiro.",
    "Invalid directory." : "Diretoria inválida.",
    "Files" : "Ficheiros",
    "All files" : "Todos os ficheiros",
    "Favorites" : "Favoritos",
    "Home" : "Casa",
    "Close" : "Fechar",
    "Upload cancelled." : "Envio cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Incapaz de enviar {filename}, dado que é uma pasta, ou tem 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "O tamanho total do ficheiro {size1} excede o limite de carregamento {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Não existe espaço suficiente. Está a enviar {size1} mas apenas existe {size2} disponível",
    "Error uploading file \"{fileName}\": {message}" : "Erro ao carregar o ficheiro \"{fileName}\": {message}",
    "Could not get result from server." : "Não foi possível obter o resultado do servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Envio de ficheiro em progresso. Se deixar a página agora, irá cancelar o envio.",
    "Actions" : "Ações",
    "Download" : "Descarregar",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Disconnect storage" : "Desconete o armazenamento",
    "Unshare" : "Cancelar partilha",
    "Details" : "Detalhes",
    "Select" : "Selecionar",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossível determinar a data",
    "This operation is forbidden" : "Esta operação é proibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", alvo já existe",
    "Could not move \"{file}\"" : "Não foi possivel mover o ficheiro \"{file}\"",
    "{newName} already exists" : "{newName} já existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", pois já não existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em uso na pasta \"{dir}\". Por favor escolha um nome diferente.",
    "Could not rename \"{fileName}\"" : "Não foi possível renomear \"{fileName}\"",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create folder \"{dir}\"" : "Não foi possível criar a pasta \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Não foi possível criar a pasta \"{dir}\", porque esta já existe",
    "Error deleting file \"{fileName}\"." : "Erro ao apagar o ficheiro \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Nenhumas entradas nesta pasta correspondem a '{filter}'",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar ficheiros aqui",
    "_Uploading %n file_::_Uploading %n files_" : ["A carregar %n ficheiro","A carregar %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O armazenamento de {owner} está cheiro. Os ficheiros já não podem ser atualizados ou sincronizados!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O armazenamento de {owner} está quase cheio ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu armazenamento está quase cheiro ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corresponde a '{filter}'","correspondem a '{filter}'"],
    "Path" : "Caminho",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Assinalado como Favorito",
    "Favorite" : "Favorito",
    "Folder" : "Pasta",
    "New folder" : "Nova Pasta",
    "{newname} already exists" : "{newname} já existe",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as tags",
    "A new file or folder has been <strong>created</strong>" : "Foi <strong>criado</strong> um novo ficheiro ou pasta",
    "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limite notificações sobre a criação e modificações nos seus <strong>ficheiros favoritos</strong> <em>(apenas Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Foi <strong>apagado</strong> um ficheiro ou pasta",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado(a)</strong> um ficheiro ou pasta",
    "You created %1$s" : "Criou %1$s",
    "%2$s created %1$s" : "%2$s criou %1$s",
    "%1$s was created in a public folder" : "%1$s foi criado numa pasta pública",
    "You changed %1$s" : "Alterou %1$s",
    "%2$s changed %1$s" : "%2$s alterou %1$s",
    "You deleted %1$s" : "Apagou %1$s",
    "%2$s deleted %1$s" : "%2$s apagou %1$s",
    "You restored %1$s" : "Restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Changed by %2$s" : "Alterado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s",
    "Upload (max. %s)" : "Enviar (max. %s)",
    "File handling" : "Manuseamento do ficheiro",
    "Maximum upload size" : "Tamanho máximo de envio",
    "max. possible: " : "Máx. possível: ",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Com o PHP-FPM pode demorar 5 minutos até que as alterações sejam aplicadas.",
    "Missing permissions to edit from here." : "Faltam permissões para editar a partir daqui.",
    "Settings" : "Definições",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilize esta ligação para <a href=\"%s\" target=\"_blank\">aceder aos seus ficheiros via WebDAV</a>",
    "Cancel upload" : "Cancelar o envio",
    "No files in here" : "Nenhuns ficheiros aqui",
    "Upload some content or sync with your devices!" : "Carregue algum conteúdo ou sincronize com os seus aparelhos!",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Select all" : "Seleccionar todos",
    "Upload too large" : "Upload muito grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiro que está a tentar enviar excedem o tamanho máximo de envio neste servidor.",
    "No favorites" : "Sem favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
    "Text file" : "Ficheiro de Texto",
    "New text file.txt" : "Novo texto ficheiro.txt"
},
"nplurals=2; plural=(n != 1);");
